import dash
from dash import dcc, html
from dash.dependencies import Input, Output
import plotly.graph_objs as go

# Create the Dash app
app = dash.Dash(__name__)

# Sample fertilizer usage data for different crops across countries (tons per hectare)
fertilizer_data = {
    'Sugar Beet': {
        'China': 6200000,
        'United States of America': 126000000,
        'Brazil': 0,
        'India': 18260,
        'Netherlands': 19900000
    },
    'Sugar Cane': {
        'China': 1500000000,
        'United States of America': 117400000,
        'Brazil': 1700000000,
        'India': 152000000,
        'Netherlands': 0
    },
    'Maize': {
        'China': 3450000000,
        'United States of America': 8100000000,
        'Brazil': 1760000000,
        'India': 131000000,
        'Netherlands': 50520000
    },
    'Rapeseed': {
        'China': 1050000000,
        'United States of America': 130400000,
        'Brazil': 0,
        'India': 87390000,
        'Netherlands': 0
    },
    'Wheat': {
        'China': 4100000000,
        'United States of America': 2220000000,
        'Brazil': 183670000,
        'India': 546190000,
        'Netherlands': 42370000
    }
}

# Define the layout of the app
app.layout = html.Div([
    html.Link(
        href="https://fonts.googleapis.com/css2?family=Source+Sans+Pro:wght@300;400;600&display=swap",
        rel="stylesheet"
    ),
    html.H1('Amount of money saved due to fertilizer omission', style={
        'color': '#185A4F',
        'font-family': 'Source Sans Pro, sans-serif'
    }),

    # Dropdown menu to select crop
    dcc.Dropdown(
        id='crop-dropdown',
        options=[{'label': crop, 'value': crop} for crop in fertilizer_data.keys()],
        value='Wheat',  # Default value
        style={
            'color': '#185A4F',
            'font-family': 'Source Sans Pro, sans-serif'
        }
    ),

    # Graph to display fertilizer usage
    dcc.Graph(id='fertilizer-bar-graph')
], style={
    'backgroundColor': '#C6EBE8',
    'padding': '20px',
    'font-family': 'Source Sans Pro, sans-serif'  # Apply font to entire app
})

# # Callback to update the graph based on the selected crop
# @app.callback(
#     Output('fertilizer-bar-graph', 'figure'),
#     [Input('crop-dropdown', 'value')]
# )
# def update_graph(selected_crop):
#     # Get the fertilizer data for the selected crop
#     countries = list(fertilizer_data[selected_crop].keys())
#     fertilizer_usage = list(fertilizer_data[selected_crop].values())

#     # Create the figure
#     figure = {
#         'data': [go.Bar(
#             x=countries,
#             y=fertilizer_usage,
#             name=selected_crop,
#             marker=dict(color='#62D881')  # Set bar color
#         )],
#         'layout': go.Layout(
#             title=f'Money saved in the cultivation of {selected_crop} Across Countries',
#             title_font=dict(color='#185A4F', family='Source Sans Pro, sans-serif'),  # Set font color for title
#             xaxis={
#                 'title': 'Countries',
#                 'titlefont': {'color': '#185A4F', 'family': 'Source Sans Pro, sans-serif'},
#                 'tickfont': {'color': '#185A4F', 'family': 'Source Sans Pro, sans-serif'}
#             },
#             yaxis={
#                 'title': 'Money saved (in US$)',
#                 'titlefont': {'color': '#185A4F', 'family': 'Source Sans Pro, sans-serif'},
#                 'tickfont': {'color': '#185A4F', 'family': 'Source Sans Pro, sans-serif'}
#             },
#             plot_bgcolor='#C6EBE8',  # Set background color for the plot
#             paper_bgcolor='#C6EBE8',  # Set background color for the entire figure
#         )
#     }

#     return figure

# Callback to update the graph based on the selected crop
@app.callback(
    Output('fertilizer-bar-graph', 'figure'),
    [Input('crop-dropdown', 'value')]
)
def update_graph(selected_crop):
    # Get the fertilizer data for the selected crop
    countries = list(fertilizer_data[selected_crop].keys())
    fertilizer_usage = list(fertilizer_data[selected_crop].values())

    # Create the figure
    figure = {
        'data': [go.Bar(
            x=countries,
            y=fertilizer_usage,
            name=selected_crop,
            marker=dict(color='#62D881')  # Set bar color
        )],
        'layout': go.Layout(
            title=f'Money saved in the cultivation of {selected_crop} Across Countries',
            title_font=dict(color='#185A4F', family='Source Sans Pro, sans-serif'),
            xaxis={
                'title': 'Countries',
                'titlefont': {'color': '#185A4F', 'family': 'Source Sans Pro, sans-serif'},
                'tickfont': {'color': '#185A4F', 'family': 'Source Sans Pro, sans-serif'}
            },
            yaxis={
                'title': 'Money saved (in US$)',
                'titlefont': {'color': '#185A4F', 'family': 'Source Sans Pro, sans-serif'},
                'tickfont': {'color': '#185A4F', 'family': 'Source Sans Pro, sans-serif'},
                'dtick': 200000000  # Set tick interval to $200 million
            },
            plot_bgcolor='#C6EBE8',
            paper_bgcolor='#C6EBE8',
            height=800  # Increase the height of the graph
        )
    }

    return figure
# Run the app
if __name__ == '__main__':
    app.run_server(debug=True)